function [deltaV,lambda]=nma_rocket_solveRocketEquationOneStage_form2(epsilon,mL,mp,Isp)
%Solves rocket equation for delta V, mass of properellent and mass of structure and payload

%function [deltaV,lambda]=nma_rocket_solveRocketEquationOneStage_form2(epsilon,mL,mp,ms,Isp)
%
% Solves the rocket equation for delta V given Mp (mass of properellent) 
% and Ms (mass of structure) and mL (payload) and Isp and epsilon for a 
% one stage rocket.
%
% Input: 
%   epsilon: The structral mass ratio ( defined as ms/(mp+ms) ).
%   mL: the mass of the payload to carry. in kg.
%   mp: mass of properllent in kg
%   Isp: the specific impulse. in seconds.
%
% Output:
%   deltaV: the speed gain in meters/seconds possible with this rocket.
%   lambda: the payload ratio= mL/(ms+mp)
%
% Author: Nasser Abbasi
% May 30, 2003
% 

g    =  9.8066;   % conversion factor
ms   =  (epsilon*mp)/(1-epsilon); 
m0   =  ms+mp+mL;
mf   =  ms+mL;
deltaV = g*Isp*log(m0/mf);
lambda = mL/(mp+ms);